@@ -1,52 +1,38 @@
-from ._models_hyperelasticity import (
-    NeoHooke,
-)
+from ._models_hyperelasticity import NeoHooke
 
 try:
     from ._models_hyperelasticity_ad import (
         isochoric_volumetric_split,
         neo_hooke,
-        yeoh,
-        third_order_deformation,
         ogden,
+        third_order_deformation,
+        yeoh,
     )
 except:
     pass
 
 from ._models_linear_elasticity import (
     LinearElastic,
-    LinearElasticTensorNotation,
-    LinearElasticPlaneStress,
     LinearElasticPlaneStrain,
+    LinearElasticPlaneStress,
+    LinearElasticTensorNotation,
     lame_converter,
 )
-
-from ._models_pseudo_elasticity import (
-    OgdenRoxburgh,
-)
-
+from ._models_pseudo_elasticity import OgdenRoxburgh
 from ._user_materials import (
+    LinearElasticPlasticIsotropicHardening,
     UserMaterial,
     UserMaterialStrain,
-    LinearElasticPlasticIsotropicHardening,
 )
 
 try:
-    from ._user_materials_hyperelastic import (
-        UserMaterialHyperelastic,
-    )
+    from ._user_materials_hyperelastic import UserMaterialHyperelastic
 except:
     pass
 
+from ._kinematics import AreaChange, LineChange, VolumeChange
+from ._mixed import ThreeFieldVariation
 from ._user_materials_models import (
     linear_elastic,
     linear_elastic_plastic_isotropic_hardening,
 )
-
-from ._kinematics import (
-    LineChange,
-    AreaChange,
-    VolumeChange,
-)
-
-from ._mixed import ThreeFieldVariation
