@@ -1,19 +1,14 @@
-from ._solidbody import SolidBody
-from ._solidbody_incompressible import (
-    SolidBodyNearlyIncompressible,
-)
-from ._helpers import StateNearlyIncompressible
-from ._solidbody_pressure import SolidBodyPressure
-from ._solidbody_gravity import SolidBodyGravity
-from ._pointload import PointLoad
-from ._step import Step
-from ._job import Job
 from ._curve import CharacteristicCurve
+from ._helpers import StateNearlyIncompressible
+from ._job import Job
+from ._pointload import PointLoad
+from ._solidbody import SolidBody
+from ._solidbody_gravity import SolidBodyGravity
+from ._solidbody_incompressible import SolidBodyNearlyIncompressible
+from ._solidbody_pressure import SolidBodyPressure
+from ._step import Step
 
 try:
-    from ._multipoint import (
-        MultiPointConstraint,
-        MultiPointContact,
-    )
+    from ._multipoint import MultiPointConstraint, MultiPointContact
 except:
     pass
