@@ -1,7 +1,4 @@
 from ._base import Scheme
-from ._triangle import Triangle
+from ._gausslegendre import GaussLegendre, GaussLegendreBoundary
 from ._tetra import Tetrahedron
-from ._gausslegendre import (
-    GaussLegendre,
-    GaussLegendreBoundary,
-)
+from ._triangle import Triangle
